import { Storage, StorageType } from '../helpers/storage';
export declare const DefaultEndpoints: {
    Google: string;
    Microsoft: string;
    Facebook: string;
    AzureAD: string;
    Dropbox: string;
};
export interface IEndpointConfiguration {
    provider?: string;
    clientId?: string;
    baseUrl?: string;
    authorizeUrl?: string;
    redirectUrl?: string;
    tokenUrl?: string;
    scope?: string;
    resource?: string;
    state?: boolean;
    nonce?: boolean;
    responseType?: string;
    extraQueryParameters?: {
        [index: string]: string;
    };
}
/**
 * Helper for creating and registering OAuth Endpoints.
 */
export declare class EndpointStorage extends Storage<IEndpointConfiguration> {
    /**
     * @constructor
    */
    constructor(storageType?: StorageType);
    /**
     * Extends Storage's default add method.
     * Registers a new OAuth Endpoint.
     *
     * @param {string} provider Unique name for the registered OAuth Endpoint.
     * @param {object} config Valid Endpoint configuration.
     * @see {@link IEndpointConfiguration}.
     * @return {object} Returns the added endpoint.
     */
    add(provider: string, config: IEndpointConfiguration): IEndpointConfiguration;
    /**
     * Register Google Implicit OAuth.
     * If overrides is left empty, the default scope is limited to basic profile information.
     *
     * @param {string} clientId ClientID for the Google App.
     * @param {object} config Valid Endpoint configuration to override the defaults.
     * @return {object} Returns the added endpoint.
     */
    registerGoogleAuth(clientId: string, overrides?: IEndpointConfiguration): IEndpointConfiguration;
    /**
     * Register Microsoft Implicit OAuth.
     * If overrides is left empty, the default scope is limited to basic profile information.
     *
     * @param {string} clientId ClientID for the Microsoft App.
     * @param {object} config Valid Endpoint configuration to override the defaults.
     * @return {object} Returns the added endpoint.
     */
    registerMicrosoftAuth(clientId: string, overrides?: IEndpointConfiguration): void;
    /**
     * Register Facebook Implicit OAuth.
     * If overrides is left empty, the default scope is limited to basic profile information.
     *
     * @param {string} clientId ClientID for the Facebook App.
     * @param {object} config Valid Endpoint configuration to override the defaults.
     * @return {object} Returns the added endpoint.
     */
    registerFacebookAuth(clientId: string, overrides?: IEndpointConfiguration): void;
    /**
     * Register AzureAD Implicit OAuth.
     * If overrides is left empty, the default scope is limited to basic profile information.
     *
     * @param {string} clientId ClientID for the AzureAD App.
     * @param {string} tenant Tenant for the AzureAD App.
     * @param {object} config Valid Endpoint configuration to override the defaults.
     * @return {object} Returns the added endpoint.
     */
    registerAzureADAuth(clientId: string, tenant: string, overrides?: IEndpointConfiguration): void;
    /**
     * Register Dropbox Implicit OAuth.
     * If overrides is left empty, the default scope is limited to basic profile information.
     *
     * @param {string} clientId ClientID for the Dropbox App.
     * @param {object} config Valid Endpoint configuration to override the defaults.
     * @return {object} Returns the added endpoint.
     */
    registerDropboxAuth(clientId: string, overrides?: IEndpointConfiguration): void;
    /**
     * Helper to generate the OAuth login url.
     *
     * @param {object} config Valid Endpoint configuration.
     * @return {object} Returns the added endpoint.
     */
    static getLoginParams(endpointConfig: IEndpointConfiguration): {
        url: string;
        state: number;
    };
}
