/**
 * Helper for creating and querying Dictionaries.
 * A wrapper around ES6 Maps.
 */
export declare class Dictionary<T> {
    protected _items: Map<string, T>;
    /**
     * @constructor
     * @param {object} items Initial seed of items.
     */
    constructor(items?: {
        [index: string]: T;
    } | Array<[string, T]> | Map<string, T>);
    /**
     * Gets an item from the dictionary.
     *
     * @param {string} key The key of the item.
     * @return {object} Returns an item if found.
     */
    get(key: string): T;
    /**
     * Inserts an item into the dictionary.
     * If an item already exists with the same key, it will be overridden by the new value.
     *
     * @param {string} key The key of the item.
     * @param {object} value The item to be added.
     * @return {object} Returns the added item.
     */
    set(key: string, value: T): T;
    /**
     * Removes an item from the dictionary.
     * Will throw if the key doesn't exist.
     *
     * @param {string} key The key of the item.
     * @return {object} Returns the deleted item.
     */
    delete(key: string): T;
    /**
     * Clears the dictionary.
     */
    clear(): void;
    /**
     * Check if the dictionary contains the given key.
     *
     * @param {string} key The key of the item.
     * @return {boolean} Returns true if the key was found.
     */
    has(key: string): boolean;
    /**
     * Lists all the keys in the dictionary.
     *
     * @return {array} Returns all the keys.
     */
    keys(): Array<string>;
    /**
     * Lists all the values in the dictionary.
     *
     * @return {array} Returns all the values.
     */
    values(): Array<T>;
    /**
     * Get a shallow copy of the underlying map.
     *
     * @return {object} Returns the shallow copy of the map.
     */
    clone(): Map<string, T>;
    /**
     * Number of items in the dictionary.
     *
     * @return {number} Returns the number of items in the dictionary.
     */
    get count(): number;
    private _validateKey;
}
