export declare enum StorageType {
    LocalStorage = 0,
    SessionStorage = 1,
    InMemoryStorage = 2
}
export interface Subscription {
    closed: boolean;
    unsubscribe(): void;
}
/**
 * Helper for creating and querying Local Storage or Session Storage.
 * Uses {@link Dictionary} so all the data is encapsulated in a single
 *  storage namespace. Writes update the actual storage.
 */
export declare class Storage<T> {
    container: string;
    private _type;
    private _storage;
    private _observable;
    private _containerRegex;
    /**
     * @constructor
     * @param {string} container Container name to be created in the LocalStorage.
     * @param {StorageType} type[optional] Storage Type to be used, defaults to Local Storage.
     */
    constructor(container: string, _type?: StorageType);
    /**
     * Switch the storage type.
     * Switches the storage type and then reloads the in-memory collection.
     *
     * @type {StorageType} type The desired storage to be used.
     */
    switchStorage(type: StorageType): void;
    /**
     * Gets an item from the storage.
     *
     * @param {string} key The key of the item.
     * @return {object} Returns an item if found.
     */
    get(key: string): T;
    /**
     * Inserts an item into the storage.
     * If an item already exists with the same key,
     * it will be overridden by the new value.
     *
     * @param {string} key The key of the item.
     * @param {object} value The item to be added.
     * @return {object} Returns the added item.
     */
    set(key: string, value: T): T;
    /**
     * Removes an item from the storage.
     * Will throw if the key doesn't exist.
     *
     * @param {string} key The key of the item.
     * @return {object} Returns the deleted item.
     */
    delete(key: string): T;
    /**
     * Clear the storage.
     */
    clear(): void;
    /**
     * Check if the storage contains the given key.
     *
     * @param {string} key The key of the item.
     * @return {boolean} Returns true if the key was found.
     */
    has(key: string): boolean;
    /**
     * Lists all the keys in the storage.
     *
     * @return {array} Returns all the keys.
     */
    keys(): Array<string>;
    /**
     * Lists all the values in the storage.
     *
     * @return {array} Returns all the values.
     */
    values(): Array<T>;
    /**
     * Number of items in the store.
     *
     * @return {number} Returns the number of items in the dictionary.
     */
    get count(): number;
    /**
     * Clear all storages.
     * Completely clears both the localStorage and sessionStorage.
     */
    static clearAll(): void;
    /**
     * Returns an observable that triggers every time there's a Storage Event
     * or if the collection is modified in a different tab.
     */
    notify(next: () => void, error?: (error: any) => void, complete?: () => void): Subscription;
    private _validateKey;
    /**
     * Determine if the value was a Date type and if so return a Date object instead.
     * https://blog.mariusschulz.com/2016/04/28/deserializing-json-strings-as-javascript-date-objects
     */
    private _reviver;
    /**
     * Scope the key to the container as @<container>/<key> so as to easily identify
     * the item in localStorage and reduce collisions
     * @param key key to be scoped
     */
    private _scope;
}
